-- LISTING 1: Partition Orders by the orderid Column

-- Create another partitioned view, with orderid as the partitioning column

-- Run on Node1
:CONNECT SQLHASP1\SQLDEV01
GO

USE testdb
GO

-- Create the partitioned table on Node1
CREATE TABLE OrdersA(
  orderid        int          NOT NULL,
  customerid     nchar(5)     NOT NULL,
  employeeid     int          NULL,
  orderdate      datetime     NULL,
  requireddate   datetime     NULL,
  shippeddate    datetime     NULL,
  shipvia        int          NULL,
  freight        money        NULL,
  shipname       nvarchar(40) NULL,
  shipaddress    nvarchar(60) NULL,
  shipcity       nvarchar(15) NULL,
  shipregion     nvarchar(15) NULL,
  shippostalcode nvarchar(10) NULL,
  shipcountry    nvarchar(15) NULL,
  CONSTRAINT PK_Orders1 PRIMARY KEY CLUSTERED(orderid),
-- This is our partitioning constraint
  CONSTRAINT CHK_Orders1 CHECK (orderid < 10500))
GO

-- Run on Node2
:CONNECT SQLHASP1\SQLDEV02
GO

USE testdb
GO
-- Create the partitioned table on Node2
CREATE TABLE OrdersB(
  orderid        int          NOT NULL,
  customerid     nchar(5)     NOT NULL,
  employeeid     int          NULL,
  orderdate      datetime     NULL,
  requireddate   datetime     NULL,
  shippeddate    datetime     NULL,
  shipvia        int          NULL,
  freight        money        NULL,
  shipname       nvarchar(40) NULL,
  shipaddress    nvarchar(60) NULL,
  shipcity       nvarchar(15) NULL,
  shipregion     nvarchar(15) NULL,
  shippostalcode nvarchar(10) NULL,
  shipcountry    nvarchar(15) NULL,
  CONSTRAINT PK_OrdersA PRIMARY KEY CLUSTERED(orderid),
-- This is our partitioning constraint
  CONSTRAINT CHK_OrdersA CHECK (orderid between 10500 and 10750))
GO

-- Run on Node3
:CONNECT SQLHASP1\SQLEXPRESS
GO

USE testdb
GO
-- Create the partitioned table on Node3
CREATE TABLE OrdersC(
  orderid        int          NOT NULL,
  customerid     nchar(5)     NOT NULL,
  employeeid     int          NULL,
  orderdate      datetime     NULL,
  requireddate   datetime     NULL,
  shippeddate    datetime     NULL,
  shipvia        int          NULL,
  freight        money        NULL,
  shipname       nvarchar(40) NULL,
  shipaddress    nvarchar(60) NULL,
  shipcity       nvarchar(15) NULL,
  shipregion     nvarchar(15) NULL,
  shippostalcode nvarchar(10) NULL,
  shipcountry    nvarchar(15) NULL,
  CONSTRAINT PK_OrdersC PRIMARY KEY CLUSTERED(orderid),
-- This is our partitioning constraint
  CONSTRAINT CHK_OrdersC CHECK (orderid > 10750))
GO

-- Run on Node1
:CONNECT SQLHASP1\SQLDEV01
GO

-- Create the partitioned view on Node1
USE testdb
GO
CREATE VIEW dbo.Orders2
AS

SELECT * FROM OrdersA
UNION ALL
SELECT * FROM Node2.testdb.dbo.OrdersB
UNION ALL
SELECT * FROM Node3.testdb.dbo.OrdersC
GO

-- Run on Node1
-- Populate the view
SET XACT_ABORT ON
GO
INSERT INTO dbo.Orders2
  SELECT * FROM Northwind.dbo.Orders
GO

SELECT * FROM dbo.Orders2
GO

SELECT * FROM testdb.dbo.OrdersA
GO

-- this one only queries one server (SQLDEV02), but
-- if all servers aren't up this will fail
SELECT * FROM dbo.Orders2
 WHERE orderid BETWEEN 10600 AND 10700

-- now bring down SQLEXPRESS instance 
SELECT * FROM dbo.Orders2
 WHERE orderid BETWEEN 10600 AND 10700

-- if that works, try this query
SELECT * FROM dbo.Orders2
 WHERE orderid BETWEEN 10600 AND 10701


